==> downloads.html?file=gigkalender_v1.2.64_009.zip: gigkalender/news/functions.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
function NewsBackendNavigation ()
  {
    global $AnzahlSeiten;
    if ( $AnzahlSeiten>'1' )
    {
      global $aktuelleSeite;
      global $L_111;

      $temp = '<div class="GigNavigation">'.$L_111.': ';
      $i = '1';
      while ($i <= $AnzahlSeiten)
      {
        if ($aktuelleSeite == $i) { $temp = $temp.'<b>'.$i.'</b> '; }
        else { $temp = $temp.'<a href="index.php?submenue=news&amp;inhalt=backend_showAllNews&amp;page='.$i.'">'.$i.'</a> '; }
        $i++;
      }
     $temp = $temp.'</div>';
    }
    else $temp = '';
    return $temp;
  }
  
function convertString ( $String )
{
  $String = str_replace("<","&lt;",$String);
  $String = str_replace(">","&gt;",$String);
  $String = str_replace("&","&amp;",$String);
  $String = str_replace('"','&quot;',$String);
  $String = str_replace("'","&apos;",$String);
  return $String;
}
  
function getTimeStringRFC3339 ($Timestamp)
{
  // get TimeZone
  $timeZone = date('O', $Timestamp);
  // create first part of AtomTime
  $atomTime[0] = date('Y-m-d\TH:i:s', $Timestamp );
  // build second part of AtomTime
  $atomTime[1] = substr($timeZone,0,3). ':' .substr($timeZone,3,2);
  // merge the 2 parts to one
  $atomTimeString = implode('', $atomTime);
  return $atomTimeString;
}
  
function writeAllFeeds ()
{
  writeAtomFeed();
  writeRSSFeed();
}
  
function writeAtomFeed ()
{
  global $db_name;
  global $prefix;
  global $GigKalenderPath;
  global $GigKalenderVersion;
  $SetupNewsChannelURL = getSetup('SetupNewsChannelURL');
  $path = str_replace("\\","/",dirname(__FILE__));
  $path = str_replace("/news","/news",$path);
  $aktuellerEintrag = AnzahlVeroeffentlichterNewsInDatenbank();

  $String = '<?xml version="1.0" encoding="utf-8"?>
  <feed xmlns="http://www.w3.org/2005/Atom">
  <title>'.getSetup('SetupNewsChannelTitle').'</title>
  <subtitle type="text">'.getSetup('SetupNewsChannelDescription').'</subtitle>
  <updated>'.getTimeStringRFC3339(time()).'</updated>
  <link href="'.$GigKalenderPath.'news/news.atom" rel="self" />
  <generator>GigKalender '.$GigKalenderVersion.'</generator>
  <rights>'.getSetup('SetupNewsChannelCopyright').'</rights>
  <id>'.getSetup('SetupNewsChannelURL').'</id>';
  

  // NewsFeed schreiben
    $sql = "SELECT * FROM ".$prefix."news order by Date DESC";
    $result = mysql_db_query($db_name, $sql);
    $datei = $path."/news.atom";
    $fp=fopen($datei,"w+");

    while ($row = mysql_fetch_array($result))
    {
      extract($row);
      if ( $Publish=='1' )
      {
        if ( substr_count($SetupNewsChannelURL, '?')) $URL = $SetupNewsChannelURL.'&amp;';
        else $URL = $SetupNewsChannelURL.'?';
        $URL = $URL.'NewsID='.$aktuellerEintrag.'#news'.$aktuellerEintrag;

        $AuthorEmailadress = getUserVar ($AddedFrom, 'UserEmailadress');
        if ( $AuthorEmailadress!='' ) $Email = '<email>'.$AuthorEmailadress.'</email>';
        else $Email = '';
        
        $Title = convertString ( $Title );
        
        $String = $String.'
  <entry>
    <title>'.$Title.'</title>
    <content type="xhtml" xml:lang="'.getSetup('SetupNewsChannelLanguage').'">
      <div xmlns="http://www.w3.org/1999/xhtml">'.$Text.'</div>
    </content>
    <author>
      <name>'.$AddedFrom.'</name>
      <uri>'.getSetup('SetupNewsChannelURL').'</uri>
      '.$Email.'
    </author>
    <id>'.$URL.'</id>
    <published>'.getTimeStringRFC3339($Date).'</published>
    <link rel="alternate" href="'.$URL.'" />';
    if ($DateOfLastEdit!=NULL AND $DateOfLastEdit!=0)
    {
      $String .= '
    <updated>'.getTimeStringRFC3339($DateOfLastEdit).'</updated>';
    }
    else
    {
      $String .= '
    <updated>'.getTimeStringRFC3339($Date).'</updated>';
    }
  $String .= '
  </entry>';
      $aktuellerEintrag--;
      }
    }
    $String = $String.'
</feed>';
    fwrite($fp,$String);
}
  
function writeRSSFeed ()
{
  global $db_name;
  global $prefix;
  global $GigKalenderPath;
  global $GigKalenderVersion;
  $SetupNewsChannelURL = getSetup('SetupNewsChannelURL');
  $path = str_replace("\\","/",dirname(__FILE__));
  $path = str_replace("/news","/news",$path);
  $aktuellerEintrag = AnzahlVeroeffentlichterNewsInDatenbank();
  
  $String = '<rss version="2.0" xmlns:atom="http://www.w3.org/2005/Atom">
    <channel>
      <title>'.getSetup('SetupNewsChannelTitle').'</title>
      <link>'.getSetup('SetupNewsChannelURL').'</link>
      <atom:link href="'.$GigKalenderPath.'news/news.rss" rel="self" type="application/rss+xml" />
      <description>'.getSetup('SetupNewsChannelDescription').'</description>
      <language>'.getSetup('SetupNewsChannelLanguage').'</language>
      <copyright>'.getSetup('SetupNewsChannelCopyright').'</copyright>
      <pubDate>'.gmdate ( "D, d M Y H:i:s" ).' GMT</pubDate>
      <lastBuildDate>'.gmdate ( "D, d M Y H:i:s" ).' GMT</lastBuildDate>
      <generator>GigKalender '.$GigKalenderVersion.'</generator>';
  
  // NewsFeed schreiben
    $sql = "SELECT * FROM ".$prefix."news order by Date DESC";
    $result = mysql_db_query($db_name, $sql);
    $datei = $path."/news.rss";
    $fp=fopen($datei,"w+");

    while ($row = mysql_fetch_array($result))
    {
      extract($row);
      if ( substr_count($SetupNewsChannelURL, '?')) $URL = $SetupNewsChannelURL.'&amp;';
      else $URL = $SetupNewsChannelURL.'?';
      $URL = $URL.'NewsID='.$aktuellerEintrag.'#news'.$aktuellerEintrag;
      
      $AuthorEmailadress = getUserVar ($AddedFrom, 'UserEmailadress');
      if ( $AuthorEmailadress!='' ) $Email = '<author>'.$AuthorEmailadress.' ('.$AddedFrom.')</author>';
      else $Email = '';
      
      $Title = convertString ( $Title );

      if ( $Publish=='1' )
      {
        $String = $String.'
        <item>
          <guid>'.$URL.'</guid>
          <title>'.$Title.'</title>
          <link>'.$URL.'</link>
          <description><![CDATA['.$Text.']]></description>
          '.$Email.'
          <pubDate>'.gmdate ( "D, d M Y H:i:s", $Date ).' GMT</pubDate>
        </item>';
        $aktuellerEintrag--;
      }
    }
    $String = $String.'</channel>
    </rss>';
    fwrite($fp,$String);
}
  
function importNewsEntry ($Date, $AddedFrom, $Title, $Text, $DateOfLastEdit, $LastEditor, $Publish)
  {
    global $prefix;
    global $db_name;
    
    // HTML-Tags entfernen
      $Title = strip_tags($Title);
    $Text = str_replace("&","&amp;",$Text);
    // Maskieren spezieller Zeichen für die Verwendung in einer SQL-Anweisung
      $Title = mysql_real_escape_string($Title);
      $Text = mysql_real_escape_string($Text);
    // Leere numerische Variablen als NULL definieren
      if ( $Date=='' ) $Date="NULL";
      if ( $DateOfLastEdit=='' ) $DateOfLastEdit="NULL";
      if ( $Publish=='' ) $Publish="NULL";
    
    $sql = "INSERT INTO ".$prefix."news (Date, AddedFrom, Title, Text, DateOfLastEdit, LastEditor, Publish)     
      VALUES ($Date, '$AddedFrom', '$Title', '$Text', $DateOfLastEdit, '$LastEditor', $Publish)";
    $resultat = mysql_db_query($db_name, $sql);
    if ($resultat) { return true; }
    else {return false;}
}   
  
function AnzahlVeroeffentlichterNewsInDatenbank ()
  {
    global $prefix;
    global $db_name;

    $sql = "SELECT count(*) as zahl FROM ".$prefix."news WHERE Publish= '1'";
    $result = mysql_db_query($db_name, $sql);
    $row = mysql_fetch_array($result);
    return $row['zahl'];
  }
  
function NewsNavigation ( $Locator )
  {
    global $AnzahlSeiten;
    global $aktuelleSeite;
    global $L_111;
    global $L_112;
    global $NewsID;

    $temp = '<div class="NewsNavigation">'.$L_111.': ';
    $Seitenzahl = $AnzahlSeiten;

    // $FormActionURL = str_replace("?NewsID=".$NewsID, "", $_SERVER['REQUEST_URI']);
    // $FormActionURL = getSetup('SetupNewsChannelURL');
    $URL = getSetup('SetupNewsChannelURL');
    $URL = str_replace("&","&amp;",$URL);
    if ( preg_match ( '|\?|', $URL ) ) $URL = $URL.'&amp;';
      else $URL = $URL.'?';
    
    while ($Seitenzahl >= 1)
    { 
      $FormActionURL = $URL.'page='.$Seitenzahl;
      if ($aktuelleSeite == $Seitenzahl) { $temp = $temp.'<b>'.$Seitenzahl.'</b> '; }
      else { $temp = $temp.'<form style="display:inline" id="form'.$Seitenzahl.$Locator.'" method="post" action="'.$FormActionURL.'" accept-charset="UTF-8">
                              <p style="display:inline">
                                <input type="hidden" name="page" value="'.$Seitenzahl.'" />
                                <a href="'.$FormActionURL.'" onclick="javascript:document.forms[\'form'.$Seitenzahl.$Locator.'\'].submit()">'.$Seitenzahl.'</a>
                              </p>
                            </form>&nbsp;'; }
      $Seitenzahl--;
    }
    $temp = $temp.'</div>';
    $temp = preg_replace ('/(\r\n|\n|\r)/', '', $temp);
    $temp = str_replace("  ", "", $temp);
    return $temp;
  }
  
function editNews ($NewsID, $Title, $Text, $Publish)
{
  global $prefix;
  global $db_name;
  
  // HTML-Tags entfernen
    $Title = strip_tags($Title);
  $DateOfLastEdit = date("U");
  // Maskieren spezieller Zeichen für die Verwendung in einer SQL-Anweisung
  $Title = mysql_real_escape_string($Title);
  $Text = mysql_real_escape_string($Text);
      
  $sql = "UPDATE ".$prefix."news SET
        Title = '".$Title."',
        Text = '".$Text."',
        Publish = '".$Publish."',
        DateOfLastEdit = '".$DateOfLastEdit."',
        LastEditor = '".getCurrentUserVar('UserName')."'
        WHERE NewsID = '".$NewsID."'
        LIMIT 1";
      $resultat = mysql_db_query($db_name, $sql);
      if ($resultat) { writeAllFeeds(); return true; }
      else {return false;}
}

function  changePublishing ( $Date )
{
  global $prefix;
  global $db_name;
  
  // aktuellen Status abfragen
  $sql = "SELECT Publish
    FROM ".$prefix."news
    WHERE Date='".$Date."'
    LIMIT 1";
  $result = mysql_db_query($db_name, $sql);
  if ( mysql_num_rows($result)==1)
  {
    $temp=mysql_fetch_assoc($result);
    $aktuellerStatus = $temp['Publish'];
  }
  // neuen Status setzen
  if ( $aktuellerStatus=='0' OR $aktuellerStatus=='NULL') $Publish = '1';
  if ( $aktuellerStatus=='1' ) $Publish = '0';
  $DateOfLastEdit = date("U");

  // Leere numerische Variablen als NULL definieren
    if ( $DateOfLastEdit=='' ) $DateOfLastEdit="NULL";
    if ( $Publish=='' ) $Publish="NULL";

  $sql = "UPDATE ".$prefix."news SET 
    Publish = ".$Publish.",
    DateOfLastEdit = ".$DateOfLastEdit.",
    LastEditor = '".getCurrentUserVar('UserName')."'
    WHERE Date = '".$Date."' LIMIT 1";
  $resultat = mysql_db_query($db_name, $sql);
  if ($resultat) { writeAllFeeds(); return true; }
    else {return false;}
}  
  
function addNews ($Title, $Text, $Publish)
  {
    global $prefix;
    global $db_name;
    /// echo $Title.' '.$Text.' '.$Publish.'<br >';
    // HTML-Tags entfernen
      $Title = strip_tags($Title);
    // Sonderzeichen umwandeln
      //$Title = htmlspecialchars($Title, ENT_QUOTES);
      //$Text = htmlspecialchars($Text, ENT_QUOTES);
    $Text = str_replace("&","&amp;",$Text);
    // tinyMCE-URL-Escapes entfernen
      $Text = str_replace('\"','"',$Text);
    $Date = date("U");
    // Maskieren spezieller Zeichen für die Verwendung in einer SQL-Anweisung
      $Title = mysql_real_escape_string($Title);
      $Text = mysql_real_escape_string($Text);

    // Leere numerische Variablen als NULL definieren
      if ( $Date=='' ) $Date="NULL";
      //if ( $DateOfLastEdit=='' ) $DateOfLastEdit="NULL";
      if ( $Publish=='' ) $Publish="NULL";
    
    $sql = "INSERT INTO ".$prefix."news (Date, AddedFrom, Title, Text, DateOfLastEdit, Publish)      
      VALUES ($Date, '".getCurrentUserVar('UserName')."', '$Title', '$Text', NULL, $Publish)";
    /// echo $sql.'<br >';
    $resultat = mysql_db_query($db_name, $sql);
    if ($resultat) { writeAllFeeds(); return true; }
    else {return false;}
}  

function AnzahlAllerNewsInDatenbank ()
  {
    global $prefix;
    global $db_name;

    $sql = "SELECT count(*) as zahl FROM ".$prefix."news";
    $result = mysql_db_query($db_name, $sql);
    $row = mysql_fetch_array($result);
    return $row['zahl'];
  }
?>

==> downloads.html?file=gigkalender_v1.2.80_040.zip: gigkalender/news/functions.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/

function getNewsBackEndPagination ():string {
  global $AnzahlSeiten;
  if ( $AnzahlSeiten>'1' ) {
    global $aktuelleSeite;
    //global $L_111;
    $output = '<div class="GigNavigation">';
    $URL = "index.php?submenue=news&amp;content=backend_showAllNews";
    $output .= getPagination ($URL, $AnzahlSeiten, $aktuelleSeite, "ASC", "page");
    $output .= '</div>'; }
  else $output = '';
  return $output; }

function getNewsFrontendNavigation ($Locator):String {
  global $AnzahlSeiten;
  global $aktuelleSeite;
  global $L_111;
  $URL = getFrontendURL('SetupNewsChannelURL');
  $output = '<div class="NewsNavigation">'.$L_111.': ';
  $output .= getPagination($URL, $AnzahlSeiten, $aktuelleSeite, "DESC", "news_page");
  return $output .= '</div>'; }

function convertString ( $String )
{
  $String = str_replace("<","&lt;",$String);
  $String = str_replace(">","&gt;",$String);
  $String = str_replace("&","&amp;",$String);
  $String = str_replace('"','&quot;',$String);
  $String = str_replace("'","&apos;",$String);
  return $String;
}
  
function getTimeStringRFC3339 ($Timestamp)
{
  // get TimeZone
  $timeZone = date('O', $Timestamp);
  // create first part of AtomTime
  $atomTime[0] = date('Y-m-d\TH:i:s', $Timestamp );
  // build second part of AtomTime
  $atomTime[1] = substr($timeZone,0,3). ':' .substr($timeZone,3,2);
  // merge the 2 parts to one
  $atomTimeString = implode('', $atomTime);
  return $atomTimeString;
}
  
function writeAllFeeds ()
{
  writeAtomFeed();
  writeRSSFeed();
}
  
function writeAtomFeed ()
{
  global $db;
  global $prefix;
  global $GigKalenderPath;
  global $GigKalenderVersion;
  $SetupNewsChannelURL = getSetup('SetupNewsChannelURL');
  $path = str_replace("\\","/",dirname(__FILE__));
  $path = str_replace("/news","/news",$path);
  $aktuellerEintrag = AnzahlVeroeffentlichterNewsInDatenbank();

  $String = '<?xml version="1.0" encoding="utf-8"?>
  <feed xmlns="http://www.w3.org/2005/Atom">
  <title>'.getSetup('SetupNewsChannelTitle').'</title>
  <subtitle type="text">'.getSetup('SetupNewsChannelDescription').'</subtitle>
  <updated>'.getTimeStringRFC3339(time()).'</updated>
  <link href="'.$GigKalenderPath.'news/news.atom" rel="self" />
  <generator>GigKalender '.$GigKalenderVersion.'</generator>
  <rights>'.getSetup('SetupNewsChannelCopyright').'</rights>
  <id>'.getSetup('SetupNewsChannelURL').'</id>';


  // NewsFeed schreiben
    $sql = "SELECT * FROM ".$prefix."news order by Date DESC";
    $result = mysqli_query($db, $sql);
    $datei = $path."/news.atom";
    $fp=fopen($datei,"w+");

    while ($row = mysqli_fetch_array($result))
    {
      extract($row);
      if ( $Publish=='1' )
      {
        if ( substr_count($SetupNewsChannelURL, '?')) $URL = $SetupNewsChannelURL.'&amp;';
        else $URL = $SetupNewsChannelURL.'?';
        $URL = $URL.'NewsID='.$aktuellerEintrag.'#news'.$aktuellerEintrag;

        $AuthorEmailadress = getUserVar ($AddedFrom, 'UserEmailadress');
        if ( $AuthorEmailadress!='' ) $Email = '<email>'.$AuthorEmailadress.'</email>';
        else $Email = '';
        
        $Title = convertString ( $Title );
        
        $String = $String.'
  <entry>
    <title>'.$Title.'</title>
    <content type="xhtml" xml:lang="'.getSetup('SetupNewsChannelLanguage').'">
      <div xmlns="http://www.w3.org/1999/xhtml">'.$Text.'</div>
    </content>
    <author>
      <name>'.$AddedFrom.'</name>
      <uri>'.getSetup('SetupNewsChannelURL').'</uri>
      '.$Email.'
    </author>
    <id>'.$URL.'</id>
    <published>'.getTimeStringRFC3339($Date).'</published>
    <link rel="alternate" href="'.$URL.'" />';
    if ($DateOfLastEdit!=NULL AND $DateOfLastEdit!=0)
    {
      $String .= '
    <updated>'.getTimeStringRFC3339($DateOfLastEdit).'</updated>';
    }
    else
    {
      $String .= '
    <updated>'.getTimeStringRFC3339($Date).'</updated>';
    }
  $String .= '
  </entry>';
      $aktuellerEintrag--;
      }
    }
    $String = $String.'
</feed>';
    fwrite($fp,$String);
}
  
function writeRSSFeed ()
{
  global $db;
  global $prefix;
  global $GigKalenderPath;
  global $GigKalenderVersion;
  $SetupNewsChannelURL = getSetup('SetupNewsChannelURL');
  $path = str_replace("\\","/",dirname(__FILE__));
  $path = str_replace("/news","/news",$path);
  $aktuellerEintrag = AnzahlVeroeffentlichterNewsInDatenbank();
  
  $String = '<rss version="2.0" xmlns:atom="http://www.w3.org/2005/Atom">
    <channel>
      <title>'.getSetup('SetupNewsChannelTitle').'</title>
      <link>'.getSetup('SetupNewsChannelURL').'</link>
      <atom:link href="'.$GigKalenderPath.'news/news.rss" rel="self" type="application/rss+xml" />
      <description>'.getSetup('SetupNewsChannelDescription').'</description>
      <language>'.getSetup('SetupNewsChannelLanguage').'</language>
      <copyright>'.getSetup('SetupNewsChannelCopyright').'</copyright>
      <pubDate>'.gmdate ( "D, d M Y H:i:s" ).' GMT</pubDate>
      <lastBuildDate>'.gmdate ( "D, d M Y H:i:s" ).' GMT</lastBuildDate>
      <generator>GigKalender '.$GigKalenderVersion.'</generator>';
  
  // NewsFeed schreiben
    $sql = "SELECT * FROM ".$prefix."news order by Date DESC";
    $result = mysqli_query($db, $sql);
    $datei = $path."/news.rss";
    $fp=fopen($datei,"w+");

    while ($row = mysqli_fetch_array($result))
    {
      extract($row);
      if ( substr_count($SetupNewsChannelURL, '?')) $URL = $SetupNewsChannelURL.'&amp;';
      else $URL = $SetupNewsChannelURL.'?';
      $URL = $URL.'NewsID='.$aktuellerEintrag.'#news'.$aktuellerEintrag;
      
      $AuthorEmailadress = getUserVar ($AddedFrom, 'UserEmailadress');
      if ( $AuthorEmailadress!='' ) $Email = '<author>'.$AuthorEmailadress.' ('.$AddedFrom.')</author>';
      else $Email = '';
      
      $Title = convertString ( $Title );

      if ( $Publish=='1' )
      {
        $String = $String.'
        <item>
          <guid>'.$URL.'</guid>
          <title>'.$Title.'</title>
          <link>'.$URL.'</link>
          <description><![CDATA['.$Text.']]></description>
          '.$Email.'
          <pubDate>'.gmdate ( "D, d M Y H:i:s", $Date ).' GMT</pubDate>
        </item>';
        $aktuellerEintrag--;
      }
    }
    $String = $String.'</channel>
    </rss>';
    fwrite($fp,$String);
}
  
function importNewsEntry ($Date, $AddedFrom, $Title, $Text, $DateOfLastEdit, $LastEditor, $Publish)
  {
    global $prefix;
    global $db;
    
    // HTML-Tags entfernen
      $Title = strip_tags($Title);
    $Text = str_replace("&","&amp;",$Text);
    // Maskieren spezieller Zeichen für die Verwendung in einer SQL-Anweisung
      $Title = mysqli_real_escape_string($db, $Title);
      $Text = mysqli_real_escape_string($db, $Text);
    // Leere numerische Variablen als NULL definieren
      if ( $Date=='' ) $Date="NULL";
      if ( $DateOfLastEdit=='' ) $DateOfLastEdit="NULL";
      if ( $Publish=='' ) $Publish="NULL";
    
    $sql = "INSERT INTO ".$prefix."news (Date, AddedFrom, Title, Text, DateOfLastEdit, LastEditor, Publish)     
      VALUES ($Date, '$AddedFrom', '$Title', '$Text', $DateOfLastEdit, '$LastEditor', $Publish)";
    $resultat = mysqli_query($db, $sql);
    if ($resultat) { return true; }
    else {return false;}
}   
  
function AnzahlVeroeffentlichterNewsInDatenbank ()
  {
    global $prefix;
    global $db;

    $sql = "SELECT count(*) as zahl FROM ".$prefix."news WHERE Publish= '1'";
    $result = mysqli_query($db, $sql);
    $row = mysqli_fetch_array($result);
    return $row['zahl'];
  }
  
function editNews ($NewsID, $Title, $Text, $Publish)
{
  global $prefix;
  global $db;
  
  // HTML-Tags entfernen
    $Title = strip_tags($Title);
  $DateOfLastEdit = date("U");
  // Maskieren spezieller Zeichen für die Verwendung in einer SQL-Anweisung
  $Title = mysqli_real_escape_string($db, $Title);
  $Text = mysqli_real_escape_string($db, $Text);
      
  $sql = "UPDATE ".$prefix."news SET
        Title = '".$Title."',
        Text = '".$Text."',
        Publish = '".$Publish."',
        DateOfLastEdit = '".$DateOfLastEdit."',
        LastEditor = '".getCurrentUserVar('UserName')."'
        WHERE NewsID = '".$NewsID."'
        LIMIT 1";
      $resultat = mysqli_query($db, $sql);
      if ($resultat) { writeAllFeeds(); return true; }
      else {return false;}
}

function  changePublishing ( $Date )
{
  global $prefix;
  global $db;
  
  // aktuellen Status abfragen
  $sql = "SELECT Publish
    FROM ".$prefix."news
    WHERE Date='".$Date."'
    LIMIT 1";
  $result = mysqli_query($db, $sql);
  if ( mysqli_num_rows($result)==1)
  {
    $temp=mysqli_fetch_assoc($result);
    $aktuellerStatus = $temp['Publish'];
  }
  // neuen Status setzen
  if ( $aktuellerStatus=='0' OR $aktuellerStatus=='NULL') $Publish = '1';
  if ( $aktuellerStatus=='1' ) $Publish = '0';
  $DateOfLastEdit = date("U");

  // Leere numerische Variablen als NULL definieren
    if ( $DateOfLastEdit=='' ) $DateOfLastEdit="NULL";
    if ( $Publish=='' ) $Publish="NULL";

  $sql = "UPDATE ".$prefix."news SET 
    Publish = ".$Publish.",
    DateOfLastEdit = ".$DateOfLastEdit.",
    LastEditor = '".getCurrentUserVar('UserName')."'
    WHERE Date = '".$Date."' LIMIT 1";
  $resultat = mysqli_query($db, $sql);
  if ($resultat) { writeAllFeeds(); return true; }
    else {return false;}
}  
  
function addNews ($Title, $Text, $Publish)
  {
    global $prefix;
    global $db;
    /// echo $Title.' '.$Text.' '.$Publish.'<br >';
    // HTML-Tags entfernen
      $Title = strip_tags($Title);
    // Sonderzeichen umwandeln
      //$Title = htmlspecialchars($Title, ENT_QUOTES);
      //$Text = htmlspecialchars($Text, ENT_QUOTES);
    $Text = str_replace("&","&amp;",$Text);
    // tinyMCE-URL-Escapes entfernen
      $Text = str_replace('\"','"',$Text);
    $Date = date("U");
    // Maskieren spezieller Zeichen für die Verwendung in einer SQL-Anweisung
      $Title = mysqli_real_escape_string($db, $Title);
      $Text = mysqli_real_escape_string($db, $Text);

    // Leere numerische Variablen als NULL definieren
      if ( $Date=='' ) $Date="NULL";
      //if ( $DateOfLastEdit=='' ) $DateOfLastEdit="NULL";
      if ( $Publish=='' ) $Publish="NULL";
    
    $sql = "INSERT INTO ".$prefix."news (Date, AddedFrom, Title, Text, DateOfLastEdit, Publish)      
      VALUES ($Date, '".getCurrentUserVar('UserName')."', '$Title', '$Text', NULL, $Publish)";
    /// echo $sql.'<br >';
    $resultat = mysqli_query($db, $sql);
    if ($resultat) { writeAllFeeds(); return true; }
    else {return false;}
}  

function AnzahlAllerNewsInDatenbank ()
  {
    global $prefix;
    global $db;

    $sql = "SELECT count(*) as zahl FROM ".$prefix."news";
    $result = mysqli_query($db, $sql);
    $row = mysqli_fetch_array($result);
    return $row['zahl'];
  }
?>
